from bibtutils.version import __version__

__all__ = ["error", "message"]

from bibtutils.slack import error
from bibtutils.slack import message

"""Slack-related functionality for BIBT."""
